netapp_ontap.models.cluster_peer_authentication API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_peer_authentication`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterPeerAuthenticationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterPeerAuthentication object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `expiry_time GET POST PATCH`

    The time when the passphrase will expire, in ISO 8601 duration format or date and time format. The default is 1 hour.

    Example: P1DT2H3M4S or '2017-01-25T11:20:13Z'

  `generate_passphrase GET POST PATCH`

    Auto generate a passphrase when true.

  `in_use GET POST PATCH`

    The in_use field of the cluster_peer_authentication.

    Valid choices:

    - ok
    - absent
    - revoked
  `passphrase GET POST PATCH`

    A password to authenticate the cluster peer relationship.

  `state GET`

    The state field of the cluster_peer_authentication.

    Valid choices:

    - ok
    - absent
    - pending
    - problem